/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection;

import static java.util.Collections.unmodifiableCollection;

import java.util.Collection;
import java.util.HashSet;

/**
 * Implementation of the kernel introspection system service (KISS).
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public final class KernelIntrospectionSystemService {

	/** Returns the singleton instance of the service. */
	public static final KernelIntrospectionSystemService INSTANCE =
			new KernelIntrospectionSystemService();

	/** The introspective services of the kernel. */
	private final Collection<IIntrospectiveKernelService> services =
			new HashSet<IIntrospectiveKernelService>();

	/** Singleton constructor. */
	private KernelIntrospectionSystemService() {
		// nothing to do here
	}

	/**
	 * Registers the given {@link IIntrospectiveKernelService} service with
	 * {@link KernelIntrospectionSystemService KISS}.
	 */
	public void registerService(IIntrospectiveKernelService service) {
		services.add(service);
	}

	/**
	 * Returns all {@link IIntrospectiveKernelService} registered with
	 * {@link KernelIntrospectionSystemService KISS}
	 */
	public Collection<IIntrospectiveKernelService> getAllServices() {
		return unmodifiableCollection(services);
	}
}
